import { Component, ElementRef, OnInit, ViewChild } from "@angular/core";

import "dhtmlx-gantt";
declare let gantt: any;
@Component({
    selector: "gantt",
    styles: [
        `
        :host{
            display: block;
            height: 600px;
            position: relative;
            width: 100%;
        }
    `],
    template: `<form class="gantt_control">
	<input type="button" value="Zoom In" onclick="gantt.ext.zoom.zoomIn()">
	<input type="button" value="Zoom Out" onclick="gantt.ext.zoom.zoomOut()">

	<input type="radio" id="scale1" class="gantt_radio" name="scale" value="day">
	<label for="scale1">Day scale</label>

	<input type="radio" id="scale2" class="gantt_radio" name="scale" value="week">
	<label for="scale2">Week scale</label>

	<input type="radio" id="scale3" class="gantt_radio" name="scale" value="month">
	<label for="scale3">Month scale</label>

	<input type="radio" id="scale4" class="gantt_radio" name="scale" value="quarter">
	<label for="scale4">Quarter scale</label>

	<input type="radio" id="scale5" class="gantt_radio" name="scale" value="year" checked>
	<label for="scale5">Year scale</label>

</form>
    <div #gantt_here style='width: 100%; height: 100%;'></div>`,
})
export class GanttComponent implements OnInit {
    @ViewChild("gantt_here", { static: true }) ganttContainer: ElementRef;

    ngOnInit() {

        var zoomConfig = {
            levels: [
                {
                    name: "day",
                    scale_height: 27,
                    min_column_width: 80,
                    scales: [
                        { unit: "day", step: 1, format: "%d %M" }
                    ]
                },
                {
                    name: "week",
                    scale_height: 50,
                    min_column_width: 50,
                    scales: [
                        {
                            unit: "week", step: 1, format: function (date) {
                                var dateToStr = gantt.date.date_to_str("%d %M");
                                var endDate = gantt.date.add(date, -6, "day");
                                var weekNum = gantt.date.date_to_str("%W")(date);
                                return "#" + weekNum + ", " + dateToStr(date) + " - " + dateToStr(endDate);
                            }
                        },
                        { unit: "day", step: 1, format: "%j %D" }
                    ]
                },
                {
                    name: "month",
                    scale_height: 50,
                    min_column_width: 120,
                    scales: [
                        { unit: "month", format: "%F, %Y" },
                        { unit: "week", format: "Week #%W" }
                    ]
                },
                {
                    name: "quarter",
                    height: 50,
                    min_column_width: 90,
                    scales: [
                        { unit: "month", step: 1, format: "%M" },
                        {
                            unit: "quarter", step: 1, format: function (date) {
                                var dateToStr = gantt.date.date_to_str("%M");
                                var endDate = gantt.date.add(gantt.date.add(date, 3, "month"), -1, "day");
                                return dateToStr(date) + " - " + dateToStr(endDate);
                            }
                        }
                    ]
                },
                {
                    name: "year",
                    scale_height: 50,
                    min_column_width: 30,
                    scales: [
                        { unit: "year", step: 1, format: "%Y" }
                    ]
                }
            ]
        };

        gantt.ext.zoom.init(zoomConfig);
        gantt.ext.zoom.setLevel("year");
        gantt.ext.zoom.attachEvent("onAfterZoom", function (level, config) {
            var radio = document.querySelector(".gantt_radio[value='" + config.name + "']") as HTMLInputElement;
            radio.checked = true;
        })

        var radios = document.getElementsByName("scale");
        for (var i = 0; i < radios.length; i++) {
            radios[i].onclick = function (event) {
                
                gantt.ext.zoom.setLevel((event.target as HTMLInputElement).value);
            };
        }

        gantt.init(this.ganttContainer.nativeElement);

        gantt.parse({
            "data": [
                { "id": "10", "text": "Project #1", "start_date": "01-04-2025", "duration": 3, "order": 10, "progress": 0.4, "open": true },
                { "id": "1", "text": "Task #1", "start_date": "02-04-2025", "duration": 2, "order": 10, "progress": 0.6, "parent": "10" },
                { "id": "2", "text": "Task #2", "start_date": "01-04-2025", "duration": 2, "order": 20, "progress": 0.6, "parent": "10" },
                { "id": "20", "text": "Project #2", "start_date": "01-04-2025", "duration": 3, "order": 10, "progress": 0.4, "type": "project", "open": true },
                { "id": "3", "text": "Task #3", "start_date": "02-04-2025", "duration": 2, "order": 10, "progress": 0.6, "parent": "20" },
                { "id": "4", "text": "Task #4", "start_date": "01-04-2025", "duration": 2, "order": 20, "progress": 0.6, "parent": "20" }
            ],
            "links": [
                { "id": 1, "source": 1, "target": 2, "type": "0" },
                { "id": 2, "source": 2, "target": 3, "type": "0" },
                { "id": 3, "source": 3, "target": 4, "type": "0" },
                { "id": 4, "source": 2, "target": 5, "type": "0" }
            ]
        })


    }
}